@echo off
rem # ====================================================================
rem #
rem # OpenCCM: The Open CORBA Component Model Platform
rem # Copyright (C) 2000-2002 USTL - LIFL - GOAL
rem # Contact: openccm-team@objectweb.org
rem #
rem # This library is free software; you can redistribute it and/or
rem # modify it under the terms of the GNU Lesser General Public
rem # License as published by the Free Software Foundation; either
rem # version 2.1 of the License, or any later version.
rem #
rem # This library is distributed in the hope that it will be useful,
rem # but WITHOUT ANY WARRANTY; without even the implied warranty of
rem # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
rem # Lesser General Public License for more details.
rem #
rem # You should have received a copy of the GNU Lesser General Public
rem # License along with this library; if not, write to the Free Software
rem # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
rem # USA
rem #
rem # Initial developer(s):Briclet Frederic
rem # Contributor(s): Jerome Moroy -------------------------.
rem #
rem # ====================================================================
rem #
rem #  Start the OpenCCM Java AssemblyFactory.
rem #
rem # ====================================================================

setlocal

rem #  =====================
rem #  Compute Command Line
rem #  =====================



set /a nb_args=0
for %%i in (%*) do set /a nb_args=nb_args+1

if %nb_args% == 0 goto help

set /a nb=0
set with_tracing="false"
set services_list=

:initial
if "%1"=="-h" goto :help
if "%1"=="?" goto :help
if "%1" == "--tracing" goto tracing
if %nb% == %nb_args% (goto end_command_line) else (goto setName)

:tracing
set XBOOTCLASSPATH=%OpenCCM_HOMEDIR%\lib\coach_tracing_toolkit.jar;
set with_tracing="true"
set services_list=%services_list% Tracing
shift
set /a nb=nb+1
goto initial

:setName
set factory_name=%1
shift
set /a nb=nb+1
goto initial

:help
echo "usage: factory_start  [--tracing] <factory_name>"    
goto :eof



:end_command_line

:start
set WORK_DIR=%OpenCCM_CONFIG_DIR%\AssemblyFactoryManagers\%factory_name%
set FACTORY_PATH=%WORK_DIR%\%factory_name%

rem #  ============================
rem #  OpenCCM Platform installed ?
rem #  ============================

:platform_installed
call %OpenCCM_HOMEDIR%\bin\ccm_installed
if %CCM_INSTALLED%==0 goto :eof

rem #  =============
rem #  Factory started ?
rem #  =============

rem # Check if this Java AssemblyFactoryManager is already started.
if not exist %FACTORY_PATH%.PID goto :factory_not_started

echo Error: The Component AssemblyFactoryManager %factory_name% is already started!
goto :eof

:factory_not_started

mkdir %FACTORY_PATH%\



rem #  ======================
rem #  Name Service started ?
rem #  ======================

rem # Obtain the IOR of the started Name Service.
call ns_ior > %FACTORY_PATH%.tmp
for /f %%i in (%FACTORY_PATH%.tmp) do set ior_NS=%%i
del %FACTORY_PATH%.tmp

rem # Check if a Name Service is started.
if defined ior_NS goto test_trader

echo Error: The Name Service is not started!
goto :eof

:test_trader
set trader_arg= 
rem # ===========================================
rem # Obtain the IOR of the started Trading Service.
rem # ===========================================
if not exist %OpenCCM_CONFIG_DIR%\TradingService.IOR goto :launch
call trader_ior > %OpenCCM_CONFIG_DIR%\trader.tmp
for /f %%i in (%OpenCCM_CONFIG_DIR%\trader.tmp) do set ior_Trader=%%i
del %OpenCCM_CONFIG_DIR%\trader.tmp

set trader_arg=-arg -ORBInitRef -arg TradingService=%ior_Trader%

:launch
:test_dci
rem #  ======================
rem #  DCI started ?
rem #  ======================

rem # Obtain the IOR of the started DCI.
call dci_ior > %FACTORY_PATH%.tmp
for /f %%i in (%FACTORY_PATH%.tmp) do set ior_DCI=%%i
del %FACTORY_PATH%.tmp

rem # Check if a Name Service is started.
if defined ior_DCI goto test_factory

echo Error: The DCI is not started!
goto :eof


:test_factory



set jvm_args="-Dior_ns=%ior_NS%" "-Dior_dci=%ior_DCI%" "-Dwork_dir=%WORK_DIR%"
set run_id=factory_start

:service_tracing
if %with_tracing% == "false" goto run
set run_id=%run_id%_tracing


:run

if NOT EXIST %OpenCCM_CONFIG_DIR%\AssemblyFactoryManagers (
  echo Creating the %OpenCCM_CONFIG_DIR%\AssemblyFactoryManagers directory.
  mkdir %OpenCCM_CONFIG_DIR%\AssemblyFactoryManagers
)

set args=--runid %run_id% -arg NSREGISTER=OpenCCM/AssemblyFactoryManagers/%factory_name% -arg FACTORYNAME=%factory_name%  file:%OpenCCM_HOMEDIR%\xml\launcher\factory_server.xml

set LAUNCHER_JVM_ARGS=%jvm_args%
set LAUNCHER_ARGS=%args%
call openccm_launcher fork %FACTORY_PATH%.output %FACTORY_PATH%.PID

echo The AssemblyFactoryManager %factory_name% is started
